==> ytx-wechat-crm-1.0.4.tgz: package/src/lib/public.js <==
'use strict';
import uuid from 'node-uuid';
class Public{
	constructor(config,wechatapi){
		this.wechatapi = wechatapi;
		this.config = {}
		if(config && config.org){
			this.cinfg = config
		}
		this.WechatMsgTypeToCrmType  = {
		    text: 'TEXT',
		    image: 'IMAGE',
		    voice: 'AUDIO',
		    ext: 'EXTENSION'
		}
	}
	isClick(info) {
		return info.is('event') && info.param.event.toUpperCase() === 'CLICK' && info.param.eventKey === EVENT_KEY_CSR;
	};
	isCsrMessageType(info) {
		return ['text', 'image', 'voice','ext'].includes(info.MsgType);
	};
	buildMsgByInfo(info){
	    return new Promise((resolve,reject)=>{
	    	try{
				if(this.isCsrMessageType(info)){
			        // if (this.isClick(info)) {
			        //   info.MsgType = 'ext';
			        //   info.extType = 'BEGINING';
			        // }
			        let id = uuid;
			        let type = this.WechatMsgTypeToCrmType[info.MsgType];
			        this.getUserInfo(info.FromUserName).then((user)=>{
			        	if(user){
			        		info.unionid = user.unionid;
			        		info.nickname = user.nickname;
			        		info.headImg = user.headimgurl;
			        	}
			        	return this.getContent(info)
			        }).then((data)=>{
			        	let msg = {};
			        	try{
							msg = {
								"id": uuid.v1(),
								"from": {
								  "id": info.FromUserName,
								  "org": this.config.org || "TT",
								  "app": this.config.app || "TT-WECHAT",
								  "biz": this.config.biz || "TPME",
								  "channel": "WECHATZP"
								},
								"to": {
								  "org": this.config.org || "TT",
								  "app": "CRM",
								  "biz": this.config.biz || "TPME",
								  "channel": "EASEMOB"
								},
								"type": type,
								"format": data.format || null,
								"content": data.content,
								"attachmentId": data.attachmentId || null,
								"timestamp": new Date().getTime(),
								"ext": {
								  wechatUnionId: info.unionid,
								  wechatNickname: info.nickname,
								  wechatHeadImg: info.headImg,
								}
							};
						}catch(e){
							reject(e);
						}
			          resolve(msg);
			      	}).catch((err)=>{
			      		reject(err);
			      	})
			    }else{
			        reject("not csr message");
			    }
	    	}catch(e){
	    		console.log(e);
	    		reject(e);
	    	}
	    })
   }
	getContent(info){
		return new Promise((resolve,reject)=>{
			if(info.MsgType == 'text' || info.MsgType =="ext"){
				resolve({content:info.Content})
			}else{
				this.wechatapi.getMedia(info.MediaId,(err,result)=>{
					if(err){
						reject(err);
					}else{
						return this.writeFile(info,result);
					}
				})
			}
		})
	}
	writeFile(info, data, res, callback) {
		return new Promise((resolve,reject)=>{
		  const contentType = res.headers['content-type'];
		  const format = contentType.substring(contentType.indexOf('/') + 1);
		  const suffix = "." + format;
		  const attachmentId = uuid.v4();
		  const fileName = attachmentId + suffix;
		  const path = "files/crm/" + fileName;
		  return fs.writeFile(path, data, null, function(err) {
		    if (err) {
		      reject(err);
		    } else {
		      const result = {fileName:fileName,attachmentId:attachmentId,format:format}
		      resolve(result);
		    }
		  });
		})
	};
	getUserInfo(uid){
		return new Promise((resolve,reject)=>{
			this.wechatapi.getUser(uid,(err,result)=>{
				if(err){
					reject(err)
				}else{
					resolve(result);
				}
			})
		})
	}

}

module.exports = Public

==> ytx-wechat-crm-1.1.1.tgz: package/src/lib/public.js <==
'use strict';
import uuid from 'node-uuid';
import fs from 'fs';
class Public{
	constructor(config,wechatapi){
		this.wechatapi = wechatapi;
		this.config = {}
		if(config && config.org){
			this.cinfg = config
		}
		this.WechatMsgTypeToCrmType  = {
		    text: 'TEXT',
		    image: 'IMAGE',
		    voice: 'AUDIO',
		    ext: 'EXTENSION'
		}
	}
	isClick(info) {
		return info.is('event') && info.param.event.toUpperCase() === 'CLICK' && info.param.eventKey === EVENT_KEY_CSR;
	};
	isCsrMessageType(info) {
		return ['text', 'image', 'voice','ext'].includes(info.MsgType);
	};
	buildMsgByInfo(info){
	    return new Promise((resolve,reject)=>{
	    	try{
				if(this.isCsrMessageType(info)){
			        // if (this.isClick(info)) {
			        //   info.MsgType = 'ext';
			        //   info.extType = 'BEGINING';
			        // }
			        let id = uuid;
			        let type = this.WechatMsgTypeToCrmType[info.MsgType];
			        this.getUserInfo(info.FromUserName).then((user)=>{
			        	if(user){
			        		info.unionid = user.unionid;
			        		info.nickname = user.nickname;
			        		info.headImg = user.headimgurl;
			        	}
			        	return this.getContent(info);
			        }).then((data)=>{
			        	let msg = {};
			        	try{
							msg = {
								"id": uuid.v1(),
								"from": {
								  "id": info.FromUserName,
								  "org": this.config.org || "TT",
								  "app": this.config.app || "TT-WECHAT",
								  "biz": this.config.biz || "PMEC",
								  "channel": "WECHATZP"
								},
								"to": {
								  "org": this.config.org || "TT",
								  "app": "CRM",
								  "biz": this.config.biz || "PMEC",
								  "channel": "EASEMOB"
								},
								"type": type,
								"format": data.format || null,
								"content": data.content,
								"attachmentId": data.attachmentId || null,
								"timestamp": new Date().getTime(),
								"ext": {
								  wechatUnionId: info.unionid,
								  wechatNickname: info.nickname,
								  wechatHeadImg: info.headImg,
								}
							};
						}catch(e){
							reject(e);
						}
			          resolve(msg);
			      	}).catch((err)=>{
			      		reject(err);
			      	})
			    }else{
			        reject("not csr message");
			    }
	    	}catch(e){
	    		console.log(e);
	    		reject(e);
	    	}
	    })
   }
	getContent(info){
		return new Promise((resolve,reject)=>{
			if(info.MsgType == 'text' || info.MsgType =="ext"){
				resolve({content:info.Content})
			}else{
				this.wechatapi.getMedia(info.MediaId,(err,result)=>{
					if(err){
						reject(err);
					}else{
						this.writeFile(info,result).then((data)=>{
							resolve(data);
						}).catch((err)=>{
							reject(err);
						});
					}
				})
			}
		})
	}
	writeFile(info, data, res, callback) {
		return new Promise((resolve,reject)=>{
		  const format ="jpg";		
		  const suffix = "." + format;
		  const attachmentId = uuid.v4();
		  const fileName = attachmentId + suffix;
		  const path = "files/crm/" + fileName;
		  return fs.writeFile(path, data, null, function(err) {
		    if (err) {
		      reject(err);
		    } else {
		      const result = {fileName:fileName,attachmentId:attachmentId,format:format};
		      resolve(result);
		    }
		  });
		})
	};
	getUserInfo(uid){
		return new Promise((resolve,reject)=>{
			this.wechatapi.getUser(uid,(err,result)=>{
				if(err){
					reject(err)
				}else{
					resolve(result);
				}
			})
		})
	}

}

module.exports = Public
